knee_scraper

Function scrape_for_errors

source
pub fn scrape_for_errors(html: &str)
Scrapes for errors and stack traces in the HTML content.

Arguments

  • html - The HTML content of the page as a string slice.

Example

scrape_for_errors("<html><body>Error: Stack trace</body></html>");